@@ -29,14 +29,6 @@
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    /**
-     * enable high dpi support
-     */
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-#endif
-
     // Since filelight may get used when the disk is full or near full we'll not
     // want to risk caching problems. If we don't have enough space -> disable caching.
     // https://bugs.kde.org/show_bug.cgi?id=466415
@@ -61,13 +53,13 @@ int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-    KLocalizedString::setApplicationDomain("filelight");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("filelight"));
     auto config = KSharedConfig::openConfig();
     auto stateConfig = KSharedConfig::openStateConfig();
-    if (config->hasGroup("general")) {
-        auto grp = stateConfig->group("general");
-        config->group("general").copyTo(&grp);
-        config->deleteGroup("general");
+    if (config->hasGroup(QLatin1String("general"))) {
+        auto grp = stateConfig->group(QStringLiteral("general"));
+        config->group(QStringLiteral("general")).copyTo(&grp);
+        config->deleteGroup(QStringLiteral("general"));
     }
 
     KAboutData about(QStringLiteral(APP_NAME),
